Module: Calabash::Android::Operations

Includes:
TouchHelpers, WaitHelpers
Defined in:
lib/calabash-android/operations.rb

Defined Under Namespace

Classes: Device

Instance Method Summary collapse

Methods included from TouchHelpers

#tap

Methods included from WaitHelpers

#handle_error_with_options, #wait_for, #wait_for_elements_do_not_exist, #wait_for_elements_exist, #wait_poll

Instance Method Details

#app_to_background(secs) ⇒ Object



524
525
526
# File 'lib/calabash-android/operations.rb', line 524

def app_to_background(secs)
  ni
end

#backdoor(sel, arg) ⇒ Object



582
583
584
# File 'lib/calabash-android/operations.rb', line 582

def backdoor(sel, arg)
  ni
end

#cell_swipe(options = {}) ⇒ Object



499
500
501
# File 'lib/calabash-android/operations.rb', line 499

def cell_swipe(options={})
  ni
end

#check_element_does_not_exist(query) ⇒ Object



546
547
548
549
550
# File 'lib/calabash-android/operations.rb', line 546

def check_element_does_not_exist( query )
  if element_exists( query )
    screenshot_and_raise "Expected no elements to match query: #{query}"
  end
end

#check_element_exists(query) ⇒ Object



540
541
542
543
544
# File 'lib/calabash-android/operations.rb', line 540

def check_element_exists( query )
  if not element_exists( query )
    screenshot_and_raise "No element found for query: #{query}"
  end
end

#check_view_with_mark_exists(expected_mark) ⇒ Object



552
553
554
# File 'lib/calabash-android/operations.rb', line 552

def check_view_with_mark_exists(expected_mark)
  check_element_exists( "view marked:'#{expected_mark}'" )
end

#clear_app_dataObject



70
71
72
# File 'lib/calabash-android/operations.rb', line 70

def clear_app_data
  default_device.clear_app_data
end

#connect_to_test_serverObject

app life cycle



156
157
158
159
160
# File 'lib/calabash-android/operations.rb', line 156

def connect_to_test_server
  puts "Explicit calls to connect_to_test_server should be removed."
  puts "Please take a look in your hooks file for calls to this methods."
  puts "(Hooks are stored in features/support)"
end

#default_deviceObject



34
35
36
37
38
39
# File 'lib/calabash-android/operations.rb', line 34

def default_device
  unless @default_device
    @default_device = Device.new(self, ENV["ADB_DEVICE_ARG"], ENV["TEST_SERVER_PORT"], ENV["APP_PATH"], ENV["TEST_APP_PATH"])
  end
  @default_device
end

#disconnect_from_test_serverObject



162
163
164
165
166
# File 'lib/calabash-android/operations.rb', line 162

def disconnect_from_test_server
  puts "Explicit calls to disconnect_from_test_server should be removed."
  puts "Please take a look in your hooks file for calls to this methods."
  puts "(Hooks are stored in features/support)"
end

#doneObject



503
504
505
# File 'lib/calabash-android/operations.rb', line 503

def done
  ni
end

#each_item(opts = {:query => "android.widget.ListView", :post_scroll => 0.2}, &block) ⇒ Object



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/calabash-android/operations.rb', line 133

def each_item(opts={:query => "android.widget.ListView", :post_scroll => 0.2}, &block)
  uiquery = opts[:query] || "android.widget.ListView"
  skip_if = opts[:skip_if] || lambda { |i| false }
  stop_when = opts[:stop_when] || lambda { |i| false }
  check_element_exists(uiquery)
  num_items = query(opts[:query], :adapter, :count).first
  num_items.times do |item|
    next if skip_if.call(item)
    break if stop_when.call(item)

    scroll_to_row(opts[:query], item)
    sleep(opts[:post_scroll]) if opts[:post_scroll] and opts[:post_scroll] > 0
    yield(item)
  end
end

#element_does_not_exist(uiquery) ⇒ Object



528
529
530
# File 'lib/calabash-android/operations.rb', line 528

def element_does_not_exist(uiquery)
  query(uiquery).empty?
end

#element_exists(uiquery) ⇒ Object



532
533
534
# File 'lib/calabash-android/operations.rb', line 532

def element_exists(uiquery)
  not element_does_not_exist(uiquery)
end

#element_is_not_hidden(uiquery) ⇒ Object

a better name would be element_exists_and_is_not_hidden



557
558
559
# File 'lib/calabash-android/operations.rb', line 557

def element_is_not_hidden(uiquery)
   ni
end

#fail(msg = "Error. Check log for details.", options = {:prefix => nil, :name => nil, :label => nil}) ⇒ Object



91
92
93
# File 'lib/calabash-android/operations.rb', line 91

def fail(msg="Error. Check log for details.", options={:prefix => nil, :name => nil, :label => nil})
 screenshot_and_raise(msg, options)
end

#html(q) ⇒ Object



478
479
480
# File 'lib/calabash-android/operations.rb', line 478

def html(q)
  query(q).map {|e| e['html']}
end

#http(options, data = nil) ⇒ Object



474
475
476
# File 'lib/calabash-android/operations.rb', line 474

def http(options, data=nil)
  default_device.http(options, data)
end

#install_app(app_path) ⇒ Object



57
58
59
# File 'lib/calabash-android/operations.rb', line 57

def install_app(app_path)
  default_device.install_app(app_path)
end

#interpolate(recording, options = {}) ⇒ Object



570
571
572
# File 'lib/calabash-android/operations.rb', line 570

def interpolate(recording, options={})
  ni
end

#label(uiquery) ⇒ Object



447
448
449
# File 'lib/calabash-android/operations.rb', line 447

def label(uiquery)
  ni
end

#load_playback_data(recording, options = {}) ⇒ Object



562
563
564
# File 'lib/calabash-android/operations.rb', line 562

def load_playback_data(recording,options={})
  ni
end

#log(message) ⇒ Object



22
23
24
# File 'lib/calabash-android/operations.rb', line 22

def log(message)
  $stdout.puts "#{Time.now.strftime("%Y-%m-%d %H:%M:%S")} - #{message}" if (ARGV.include? "-v" or ARGV.include? "--verbose")
end

#macro(txt) ⇒ Object



26
27
28
29
30
31
32
# File 'lib/calabash-android/operations.rb', line 26

def macro(txt)
  if self.respond_to?(:step)
    step(txt)
  else
    Then(txt)
  end
end

#make_http_request(url, req) ⇒ Object



605
606
607
# File 'lib/calabash-android/operations.rb', line 605

def make_http_request( url, req )
  ni
end

#map(query, method_name, *method_args) ⇒ Object



586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/calabash-android/operations.rb', line 586

def map(query, method_name, *method_args)
  operation_map = {
      :method_name => method_name,
      :arguments => method_args
  }
  res = http("/map",
             {:query => query, :operation => operation_map})
  res = JSON.parse(res)
  if res['outcome'] != 'SUCCESS'
    screenshot_and_raise "map #{query}, #{method_name} failed because: #{res['reason']}\n#{res['details']}"
  end

  res['results']
end

#niObject



149
150
151
# File 'lib/calabash-android/operations.rb', line 149

def ni
  raise "Not yet implemented."
end

#performAction(action, *arguments) ⇒ Object



45
46
47
# File 'lib/calabash-android/operations.rb', line 45

def performAction(action, *arguments)
  default_device.perform_action(action, *arguments)
end

#pinch(in_out, options = {}) ⇒ Object



516
517
518
# File 'lib/calabash-android/operations.rb', line 516

def pinch(in_out,options={})
  ni
end

#playback(recording, options = {}) ⇒ Object



566
567
568
# File 'lib/calabash-android/operations.rb', line 566

def playback(recording, options={})
  ni
end

#press_back_keyObject



103
104
105
# File 'lib/calabash-android/operations.rb', line 103

def press_back_key
  default_device.press_back_key
end

#query(uiquery, *args) ⇒ Object

def wait_for(timeout, &block)

value = nil
begin
  Timeout::timeout(timeout) do
    until (value = block.call)
      sleep 0.3
    end
  end
rescue Exception => e
  raise e
end
value

end



121
122
123
124
125
126
127
128
129
130
131
# File 'lib/calabash-android/operations.rb', line 121

def query(uiquery, *args)
  converted_args = []
  args.each do |arg|
    if arg.is_a?(Hash) and arg.count == 1
      converted_args << {:method_name => arg.keys.first, :arguments => [ arg.values.first ]}
    else
      converted_args << arg
    end
  end
  map(uiquery,:query,*converted_args)
end

#record_beginObject



574
575
576
# File 'lib/calabash-android/operations.rb', line 574

def record_begin
  ni
end

#record_end(file_name) ⇒ Object



578
579
580
# File 'lib/calabash-android/operations.rb', line 578

def record_end(file_name)
  ni
end

#reinstall_appsObject



49
50
51
# File 'lib/calabash-android/operations.rb', line 49

def reinstall_apps
  default_device.reinstall_apps
end

#reinstall_test_serverObject



53
54
55
# File 'lib/calabash-android/operations.rb', line 53

def reinstall_test_server
  default_device.reinstall_test_server
end

#rotate(dir) ⇒ Object



520
521
522
# File 'lib/calabash-android/operations.rb', line 520

def rotate(dir)
  ni
end

#screenshot(options = {:prefix => nil, :name => nil}) ⇒ Object



87
88
89
# File 'lib/calabash-android/operations.rb', line 87

def screenshot(options={:prefix => nil, :name => nil})
  default_device.screenshot(options)
end

#screenshot_and_raise(msg) ⇒ Object



451
452
453
454
# File 'lib/calabash-android/operations.rb', line 451

def screenshot_and_raise(msg)
  screenshot_embed
  raise(msg)
end

#screenshot_embed(options = {:prefix => nil, :name => nil, :label => nil}) ⇒ Object



82
83
84
85
# File 'lib/calabash-android/operations.rb', line 82

def screenshot_embed(options={:prefix => nil, :name => nil, :label => nil})
  path = default_device.screenshot(options)
  embed(path, "image/png", options[:label] || File.basename(path))
end

#scroll(uiquery, direction) ⇒ Object



507
508
509
# File 'lib/calabash-android/operations.rb', line 507

def scroll(uiquery,direction)
  ni
end

#scroll_to_row(uiquery, number) ⇒ Object



511
512
513
514
# File 'lib/calabash-android/operations.rb', line 511

def scroll_to_row(uiquery,number)
  query(uiquery, {:smoothScrollToPosition => number})
  puts "TODO:detect end of scroll - use sleep for now"
end

#set_default_device(device) ⇒ Object



41
42
43
# File 'lib/calabash-android/operations.rb', line 41

def set_default_device(device)
  @default_device = device
end

#set_gps_coordinates(latitude, longitude) ⇒ Object



99
100
101
# File 'lib/calabash-android/operations.rb', line 99

def set_gps_coordinates(latitude, longitude)
  default_device.set_gps_coordinates(latitude, longitude)
end

#set_gps_coordinates_from_location(location) ⇒ Object



95
96
97
# File 'lib/calabash-android/operations.rb', line 95

def set_gps_coordinates_from_location(location)
  default_device.set_gps_coordinates_from_location(location)
end

#set_text(uiquery, txt) ⇒ Object



482
483
484
485
486
487
488
489
490
491
492
# File 'lib/calabash-android/operations.rb', line 482

def set_text(uiquery, txt)
  raise "Currently queries are only supported for webviews" unless uiquery.start_with? "webView"

  uiquery.slice!(0, "webView".length)
  if uiquery =~ /(css|xpath):\s*(.*)/
    r = performAction("set_text", $1, $2, txt)
    JSON.parse(r["message"])
  else
   raise "Invalid query #{uiquery}"
  end
end

#shutdown_test_serverObject



78
79
80
# File 'lib/calabash-android/operations.rb', line 78

def shutdown_test_server
  default_device.shutdown_test_server
end

#start_test_server_in_background(options = {}) ⇒ Object



74
75
76
# File 'lib/calabash-android/operations.rb', line 74

def start_test_server_in_background(options={})
  default_device.start_test_server_in_background()
end

#swipe(dir, options = {}) ⇒ Object



495
496
497
# File 'lib/calabash-android/operations.rb', line 495

def swipe(dir,options={})
    ni
end

#touch(uiquery, *args) ⇒ Object



456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/calabash-android/operations.rb', line 456

def touch(uiquery,*args)
  raise "Cannot touch nil" unless uiquery

  if uiquery.instance_of? String
    elements = query(uiquery, *args)
    raise "No elements found. Query: #{uiquery}" if elements.empty?
    element = elements.first
  else
    element = uiquery
    element = element.first if element.instance_of?(Array)
  end


  center_x = element["rect"]["center_x"]
  center_y = element["rect"]["center_y"]
  performAction("touch_coordinate", center_x, center_y)
end

#uninstall_appsObject



61
62
63
64
# File 'lib/calabash-android/operations.rb', line 61

def uninstall_apps
  default_device.uninstall_app(package_name(default_device.test_server_path))
  default_device.uninstall_app(package_name(default_device.app_path))
end

#url_for(verb) ⇒ Object



601
602
603
# File 'lib/calabash-android/operations.rb', line 601

def url_for( verb )
  ni
end

#view_with_mark_exists(expected_mark) ⇒ Object



536
537
538
# File 'lib/calabash-android/operations.rb', line 536

def view_with_mark_exists(expected_mark)
  element_exists( "android.view.View marked:'#{expected_mark}'" )
end

#wake_upObject



66
67
68
# File 'lib/calabash-android/operations.rb', line 66

def wake_up
  default_device.wake_up()
end